<?php

namespace Drupal\user_disk_quota;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines a class for dynamic permissions based on roles.
 *
 * @internal
 */
class UserDiskQuotaPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The entity type manager.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new UserDiskQuotaPermissions instance.
   *
   * @param Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity.manager'));
  }

  /**
   * Returns an array of permissions.
   *
   * @return array
   *   The permissions.
   */
  public function permissions() {
    $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    $permissions = [];

    foreach ($roles as $role) {
      $permissions["edit {$role->id()} role disk quota"] = [
        'title' => $this->t('Edit role @role users disk quota', ['@role' => $role->label()]),
      ];
    }

    return $permissions;
  }

}
